const needle = require("needle");

async function miniAtualization() {
    await needle.get('https://flzz-api.squareweb.app/api/miniatt', function (error, resp) {
        if (resp.body.news) {
            return {
                news: true,
                next_version: resp.body.next_version
            }
        } else {
            return {
                news: false,
                version: resp.body.version
            }
        }
    })
}

async function fileInfo(version) {
    await needle.get('https://flzz-api.squareweb.app/api/fileinfo/' + version, function (error, resp) {
        if (resp.statusCode == 404 || resp.body.error) {
            throw new Error('Invalid version.')
        } else {
            return Array(resp.body.downloadNames).join('\n')
        }
    })
}

async function accountCreationDate(id) {
    await needle.get('https://flzz-api.squareweb.app/api/data/' + id, function (error, resp) {
        if (resp.body.error || resp.statusCode == 404) {
            throw new Error('Invalid ID.')
        } else {
            return resp.body.date
        }
    })
}

async function version() {
    await needle.get('https://flzz-api.squareweb.app/api/version', function (error, resp) {
        if (resp.body.error) {
            throw new Error('Garena API Error')
        } else {
            return resp.body.version
        }
    })
}

async function maxVersion() {
    await needle.get('https://flzz-api.squareweb.app/api/maxversion', function (error, resp) {
        if (resp.body.error) {
            throw new Error('Garena API Error')
        } else {
            return resp.body.version
        }
    })
}

module.exports = {
    miniAtualization,
    fileInfo,
    accountCreationDate,
    version,
    maxVersion
}